Module types

Module types 

The structs and enums used by the Redis client.

Modules

clienti-client
Types used to inspect or operate on client connections.
clusteri-cluster
Types used to inspect or operate on clusters or cluster connections.
config
Types used to configure clients or commands.
geoi-geo
Types used with the GEO interface.
listsi-lists
Types used wih the lists interface.
redisearchi-redisearch
Types used with the i-redisearch interface.
scan
Types used to scan servers.
scriptsi-scripts
Types related to Lua scripts or functions.
sorted_setsi-sorted-sets
Types used in the sorted sets interface.
statsdynamic-pool
Usage statistics used to scale a DynamicPool.
streamsi-streams
Types used in the streams interface.
timeseriesi-time-series
Types used with the i-time-series interface.

Structs

Builder
A client and pool builder interface.
CustomCommand
Configuration for custom redis commands, primarily used for interacting with third party modules or extensions.
DatabaseMemoryStatsi-memory
The parsed result of the MEMORY STATS command for a specific database.
Key
A key identifying a Value.
KeyspaceEvent
An event on the publish-subscribe interface describing a keyspace notification.
Map
A map of (Key, Value) pairs.
MemoryStatsi-memory
The parsed result of the MEMORY STATS command.
Message
A publish-subscribe message.
MultipleHashSlots
A convenience struct for functions that take one or more hash slot values.
MultipleKeys
Convenience struct for commands that take 1 or more keys.
SlowlogEntry
The output of an entry in the slow queries log.
Statsmetrics
Stats describing a distribution of samples.
Version
SemVer version as defined by https://semver.org.

Enums

ClientState
The state of the underlying connection to the Redis server.
ClientUnblockFlag
Arguments to the CLIENT UNBLOCK command.
ClusterHash
A cluster hashing policy.
ClusterStateChange
An enum describing the possible ways in which a Redis cluster can change state.
Expiration
Expiration options for the set command.
ExpireOptions
Options for certain expiration commands (PEXPIRE, etc).
InfoKind
Options for the info command.
MessageKind
The kind of pubsub message.
Resp3Frame
A RESP3 frame that uses Bytes and Str as the underlying buffer type.
RespVersion
The RESP version used in the HELLO request.
SentinelFailureKindsentinel-client
Arguments for the SENTINEL SIMULATE-FAILURE command.
SetOptions
Options for the set command.
ShutdownFlags
Arguments passed to the SHUTDOWN command.
SortOrder
The sort order for redis commands that take or return a sorted list.
StringOrNumber
An argument representing a string or number.
Value
A value used in arguments or response types.
ValueKind
The kind of value from the server.

Traits

FromKey
A trait used to convert Key values to various types.
FromValue
A trait used to convert various forms of Value into different types.
Resolvedns
A trait that can be used to override DNS resolution logic.

Type Aliases

Any
The ANY flag used on certain GEO commands.
ConnectHandle
The result from any of the connect functions showing the error that closed the connection, if any.
Limit
A tuple of (offset, count) values for commands that allow paging through results.
LimitCount
An argument type equivalent to “[LIMIT count]”.
MultipleStrings
Convenience interface for commands that take 1 or more strings.
MultipleValues
Convenience interface for commands that take 1 or more values.