Module streams

Module streams 

Available on crate feature i-streams only.
Types used in the streams interface.

Structs

MultipleIDs
One or more IDs for elements in a stream.
MultipleOrderedPairs
One or more ordered key-value pairs, typically used as an argument for XADD.
XCap
Stream cap arguments for XADD, XTRIM, etc.
XPendingArgs
A struct representing the trailing optional arguments to XPENDING.

Enums

XCapKind
The MAXLEN or MINID argument for a stream cap.
XCapTrim
Representation for the “=” or “~” operator in XADD, etc.
XID
Stream ID arguments for XADD, XREAD, etc.

Type Aliases

XReadResponse
A generic helper type describing the top level response from XREAD or XREADGROUP.
XReadValue
A generic helper type describing the ID and associated map for each record in a stream.