Traits that implement portions of the Redis interface.
Enums
- Resp3
Frame - A RESP3 frame that uses Bytes and Str as the underlying buffer type.
Traits
- AclInterface
i-acl - Functions that implement the ACL interface.
- Auth
Interface - Functions for authenticating clients.
- Client
Interface i-client - Functions that implement the client interface.
- Client
Like Neither cloudflarenorglommionormonoionorsmol - Any client that implements any part of the server interface.
- Cluster
Interface i-cluster - Functions that implement the cluster interface.
- Config
Interface i-config - Functions that implement the config interface.
- Event
Interface - An interface that exposes various client and connection events.
- Function
Interface i-scripts - Functions that implement the function interface.
- GeoInterface
i-geo - Functions that implement the geo interface.
- Hashes
Interface i-hashes - Functions that implement the hashes interface.
- Heartbeat
Interface - Functions that provide a connection heartbeat interface.
- Hyperloglog
Interface i-hyperloglog - Functions that implement the HyperLogLog interface.
- Keys
Interface i-keys - Functions that implement the generic keys interface.
- List
Interface i-lists - Functions that implement the lists interface.
- LuaInterface
i-scripts - Functions that implement the lua interface.
- Memory
Interface i-memory - Functions that implement the memory interface.
- Metrics
Interface - Functions that implement the internal metrics interface.
- Pubsub
Interface i-pubsub - Functions that implement the pubsub interface.
- Redi
Search Interface i-redisearch - A RediSearch interface.
- Redis
Json Interface i-redis-json - The client commands in the RedisJSON interface.
- Sentinel
Interface sentinel-client - Functions that implement the sentinel interface.
- Server
Interface i-server - Functions that implement the server interface.
- Sets
Interface i-sets - Functions that implement the sets interface.
- Slowlog
Interface i-slowlog - Functions that implement the slowlog interface.
- Sorted
Sets Interface i-sorted-sets - Functions that implement the sorted sets interface.
- Streams
Interface i-streams - Functions that implement the streams interface.
- Time
Series Interface i-time-series - A Redis Timeseries interface.
- Tracking
Interface i-tracking - A high level interface that supports client side caching via the client tracking interface.
- Transaction
Interface transactions - Functions that implement the transactions interface.
Type Aliases
- Fred
Result - Type alias for
Result<T, Error>.