The structs and enums used by the Redis client.
Modules
- client
i-client - Types used to inspect or operate on client connections.
- cluster
i-cluster - Types used to inspect or operate on clusters or cluster connections.
- config
- Types used to configure clients or commands.
- geo
i-geo - Types used with the
GEOinterface. - lists
i-lists - Types used wih the lists interface.
- redisearch
i-redisearch - Types used with the
i-redisearchinterface. - scan
- Types used to scan servers.
- scripts
i-scripts - Types related to Lua scripts or functions.
- sorted_
sets i-sorted-sets - Types used in the sorted sets interface.
- stats
dynamic-pool - Usage statistics used to scale a DynamicPool.
- streams
i-streams - Types used in the streams interface.
- timeseries
i-time-series - Types used with the
i-time-seriesinterface.
Structs
- Builder
- A client and pool builder interface.
- Custom
Command - Configuration for custom redis commands, primarily used for interacting with third party modules or extensions.
- Database
Memory Stats i-memory - The parsed result of the MEMORY STATS command for a specific database.
- Key
- A key identifying a Value.
- Keyspace
Event - An event on the publish-subscribe interface describing a keyspace notification.
- Map
- A map of
(Key, Value)pairs. - Memory
Stats i-memory - The parsed result of the MEMORY STATS command.
- Message
- A publish-subscribe message.
- Multiple
Hash Slots - A convenience struct for functions that take one or more hash slot values.
- Multiple
Keys - Convenience struct for commands that take 1 or more keys.
- Slowlog
Entry - The output of an entry in the slow queries log.
- Stats
metrics - Stats describing a distribution of samples.
- Version
- SemVer version as defined by https://semver.org.
Enums
- Client
State - The state of the underlying connection to the Redis server.
- Client
Unblock Flag - Arguments to the CLIENT UNBLOCK command.
- Cluster
Hash - A cluster hashing policy.
- Cluster
State Change - An enum describing the possible ways in which a Redis cluster can change state.
- Expiration
- Expiration options for the set command.
- Expire
Options - Options for certain expiration commands (
PEXPIRE, etc). - Info
Kind - Options for the info command.
- Message
Kind - The kind of pubsub message.
- Resp3
Frame - A RESP3 frame that uses Bytes and Str as the underlying buffer type.
- Resp
Version - The RESP version used in the
HELLOrequest. - Sentinel
Failure Kind sentinel-client - Arguments for the
SENTINEL SIMULATE-FAILUREcommand. - SetOptions
- Options for the set command.
- Shutdown
Flags - Arguments passed to the SHUTDOWN command.
- Sort
Order - The sort order for redis commands that take or return a sorted list.
- String
OrNumber - An argument representing a string or number.
- Value
- A value used in arguments or response types.
- Value
Kind - The kind of value from the server.
Traits
- FromKey
- A trait used to convert Key values to various types.
- From
Value - A trait used to convert various forms of Value into different types.
- Resolve
dns - A trait that can be used to override DNS resolution logic.
Type Aliases
- Any
- The ANY flag used on certain GEO commands.
- Connect
Handle - The result from any of the
connectfunctions showing the error that closed the connection, if any. - Limit
- A tuple of
(offset, count)values for commands that allow paging through results. - Limit
Count - An argument type equivalent to “[LIMIT count]”.
- Multiple
Strings - Convenience interface for commands that take 1 or more strings.
- Multiple
Values - Convenience interface for commands that take 1 or more values.